calc_perm_p_value calculates the permutation p-value following PhiSmy10perm;textualrobnptests.
calc_perm_p_value(
statistic,
distribution,
m,
n,
randomization,
n.rep,
alternative
)p-value for the specified alternative.
observed value of the test statistic.
a numeric vector with the permutation/randomization distribution.
an integer value giving size of first sample.
an integer value giving size of second sample.
a logical value indicating whether the p-value should be
computed from a permutation (FALSE, default) or a
randomization (TRUE) distribution.
an integer value specifying the number of random splits used to
calculate the randomization distribution if method = "randomization".
This argument is ignored if method = "permutation" or method = "asymptotic".
The default is n.rep = 10000.
a character string specifying the alternative hypothesis, must be one of "two.sided" (default), "greater", or "less".
PhiSmy10permrobnptests