compute_results_asymptotic is a helper function to compute the test
decision for the HL1-, HL2-, and MED-test when method = "asymptotic".
compute_results_asymptotic(x, y, alternative, delta, type)A named list containing the following components:
the value of the test statistic.
the location estimates for both samples in case of the HL1- and the MED-tests. The estimate for the location difference in case of the HL2-tests.
the p-value for the test.
a (non-empty) numeric vector of data values.
a (non-empty) numeric vector of data values.
a character string specifying the alternative hypothesis, must be one of "two.sided", "greater", or "less".
a numeric value indicating the true difference in the location or scale parameter, depending on whether the test should be performed for a difference in location or in scale.
a character string specifying the desired test statistic. It must
be one of "HL11", "HL12", "HL21", "HL22", "MED1",
and "MED2", where "HL1", "HL2" and
"MED" specify the location estimator and the numbers
1 and 2 the scale estimator, see the vignette
(vignette("robnptests")) for more information.