mest_perm_distribution calculates the permutation distribution for the M-statistics from
m_test_statistic.
m_est_perm_distribution(x, y, psi, k, randomization = FALSE, n.rep = 10000)Vector with permutation distribution of the test statistic specified by psi
and k.
a (non-empty) numeric vector of data values.
a (non-empty) numeric vector of data values.
kernel used for optimization.
Must be one of "bisquare", "hampel" and "huber".
The default is "huber".
tuning parameter(s) for the respective kernel function,
defaults to parameters implemented in .Mpsi.tuning.default(psi)
in the package robustbase.
a logical value indicating whether the p-value should be
computed from a permutation (FALSE, default) or a
randomization (TRUE) distribution.
an integer value specifying the number of random splits used to
calculate the randomization distribution if method = "randomization".
The default is n.rep = 10000.
Missing values in either x or y are not allowed.
MaeRouCro22roburobnptests