Learn R Programming

robnptests (version 1.1.0)

trimmed_t: Test statistic for the two-sample trimmed t-test (Yuen's t-test)

Description

trimmed_t calculates the test statistic for the two-sample trimmed t-test.

Usage

trimmed_t(x, y, gamma = 0.2, na.rm = FALSE)

Value

A named list containing the following components:

statistic

the value of the test statistic.

estimates

the trimmed means for both samples.

df

the degrees of freedom for the test statistic.

Arguments

x

a (non-empty) numeric vector of data values.

y

a (non-empty) numeric vector of data values.

gamma

a numeric value in [0, 0.5] specifying the fraction of observations to be trimmed from each end of the sample before calculating the mean. The default value is 0.2.

na.rm

a logical value indicating whether NA values in x and y should be stripped before the computation proceeds. The default is na.rm = FALSE.

References

YueDix73apprrobnptests

Yue74trimrobnptests

Examples

Run this code
# Generate random samples
set.seed(108)
x <- rnorm(20); y <- rnorm(20)

# Compute trimmed t-statistic
trimmed_t(x, y, gamma = 0.2)

Run the code above in your browser using DataLab