powered by
hodges_lehmann calculates the one-sample Hodges-Lehmann estimator of a sample.
hodges_lehmann
hodges_lehmann(x, na.rm = FALSE)
The one-sample Hodges-Lehmann estimator.
a (non-empty) numeric vector of data values.
a logical value indicating whether NA values in x and y should be stripped before the computation proceeds. The default is na.rm = FALSE.
x
y
na.rm = FALSE
The one-sample Hodges-Lehmann estimator for a sample of size n is defined as
n
$$med(\frac{X_i + X_j}{2}, 1 \le i < j \le m).$$
HodLeh63estirobnptests
# Generate random sample set.seed(108) x <- rnorm(10) # Compute one-sample Hodges-Lehmann estimator hodges_lehmann(x)
Run the code above in your browser using DataLab