powered by
hodges_lehmann_2sample calculates the two-sample Hodges-Lehmann estimator for the location difference of two samples x and y.
hodges_lehmann_2sample
hodges_lehmann_2sample(x, y, na.rm = FALSE)
The two-sample Hodges-Lehmann estimator.
a (non-empty) numeric vector of data values.
a logical value indicating whether NA values in x and y should be stripped before the computation proceeds. The default is na.rm = FALSE.
x
y
na.rm = FALSE
The two-sample Hodges-Lehmann estimator for two samples x and y of sizes m and n is defined as
m
n
$$med(|x_i - y_j|, 1 \le i \le m, 1 \le j \le n).$$
HodLeh63estirobnptests
# Generate random samples set.seed(108) x <- rnorm(10); y <- rnorm(10) # Compute two-sample Hodges-Lehmann estimator hodges_lehmann_2sample(x, y)
Run the code above in your browser using DataLab